@@ -85,8 +85,8 @@ class Movie(_Container):
                 'miscellaneouscrew':   'miscellaneous crew',
                 'crewmembers': 'miscellaneous crew',
                 'crew members': 'miscellaneous crew',
-                'other companies':  'miscellaneous companies',
-                'misc companies': 'miscellaneous companies',
+                'misc companies': 'other companies',
+                'miscellaneous companies': 'other companies',
                 'aka':  'akas',
                 'also known as':    'akas',
                 'country':  'countries',
@@ -102,6 +102,9 @@ class Movie(_Container):
                 'soundclips':   'sound clips',
                 'videoclips':   'video clips',
                 'photographs':  'photo sites',
+                'distributor': 'distributors',
+                'distribution': 'distributors',
+                'distribution companies': 'distributors',
                 'guest': 'guests',
                 'guest appearances': 'guests',
                 'tv guests': 'guests',
