@@ -106,12 +106,15 @@ class IMDbMobileAccessSystem(IMDbHTTPAccessSystem):
         IMDbHTTPAccessSystem.__init__(self, isThin, *arguments, **keywords)
         self.accessSystem = 'mobile'
 
-    def _mretrieve(self, url):
+    def _clean_html(self, html):
+        """Normalize the retrieve html."""
+        html = re_spaces.sub(' ', html)
+        return subXMLRefs(html)
+
+    def _mretrieve(self, url, size=-1):
         """Retrieve an html page and normalize it."""
-        cont = IMDbHTTPAccessSystem._retrieve(self, url)
-        cont = re_spaces.sub(' ', cont)
-        cont = subXMLRefs(cont)
-        return cont
+        cont = self._retrieve(url, size=size)
+        return self._clean_html(cont)
 
     def _getPersons(self, s, sep='<br>', hasCr=0, aonly=0):
         """Return a list of Person objects, from the string s; items
@@ -143,6 +146,7 @@ class IMDbMobileAccessSystem(IMDbHTTPAccessSystem):
             if aonly:
                 stripped = _findBetween(name, '>', '</a>')
                 if len(stripped) == 1: name = stripped[0]
+            if name[0:1] == '>': name = name[1:]
             name = _unHtml(name)
             if not (pid and name): continue
             plappend(Person(personID=str(pid[0]), name=name,
@@ -154,8 +158,9 @@ class IMDbMobileAccessSystem(IMDbHTTPAccessSystem):
 
     def _search_movie(self, title, results):
         ##params = urllib.urlencode({'tt': 'on','mx': str(results),'q': title})
-        params = 'q=%s&tt=on&mx=%s' % (urllib.quote_plus(title), str(results))
-        cont = self._mretrieve(imdbURL_search % params)
+        #params = 'q=%s&tt=on&mx=%s' % (urllib.quote_plus(title), str(results))
+        #cont = self._mretrieve(imdbURL_search % params)
+        cont = self._get_search_content('tt', title, results)
         title = _findBetween(cont, '<title>', '</title>')
         res = []
         if not title: return res
@@ -287,23 +292,30 @@ class IMDbMobileAccessSystem(IMDbHTTPAccessSystem):
             castdata = _findBetween(cont, 'Credited cast', '</table>')
         if not castdata:
             castdata = _findBetween(cont, 'Complete credited cast', '</table>')
+        if not castdata:
+            castdata = _findBetween(cont, 'Series Cast Summary', '</table>')
         if castdata:
             castdata = castdata[0]
             fl = castdata.find('href=')
-            if fl != -1: castdata = '< a' + castdata[fl:]
+            if fl != -1: castdata = '<a ' + castdata[fl:]
             smib = castdata.find('<tr><td align="center" colspan="3"><small>')
             if smib != -1:
                 smie = castdata.rfind('</small></td></tr>')
                 if smie != -1:
                     castdata = castdata[:smib].strip() + \
                                 castdata[smie+18:].strip()
-            cast = self._getPersons(castdata, sep='</tr><tr>', hasCr=1)
+            castdata = castdata.replace(' bgcolor="#F0F0F0"', '')
+            castdata = castdata.replace(' bgcolor="#FFFFFF"', '')
+            castdata = castdata.replace('/tr> <tr', '/tr><tr')
+            cast = self._getPersons(castdata, sep='</tr><tr', hasCr=1)
             if cast: d['cast'] = cast
         # FIXME: doesn't catch "complete title", which is not
         #        included in <i> tags.
         #        See "Gehr Nany Fgbevrf 11", movieID: 0282910
-        akas = _findBetween(cont, '<i class="transl">', '<br')
+        akas = _findBetween(cont, '<b class="ch">Also Known As:</b>',
+                                    '<b class="ch">')
         if akas:
+            akas[:] = [x for x in akas[0].split('<br>') if x.strip()]
             akas = [_unHtml(x).replace(' (','::(', 1).replace(' [','::[')
                     for x in akas]
             d['akas'] = akas
@@ -359,8 +371,9 @@ class IMDbMobileAccessSystem(IMDbHTTPAccessSystem):
 
     def _search_person(self, name, results):
         ##params = urllib.urlencode({'nm': 'on', 'mx': str(results), 'q': name})
-        params = 'q=%s&nm=on&mx=%s' % (urllib.quote_plus(name), str(results))
-        cont = self._mretrieve(imdbURL_search % params)
+        #params = 'q=%s&nm=on&mx=%s' % (urllib.quote_plus(name), str(results))
+        #cont = self._mretrieve(imdbURL_search % params)
+        cont = self._get_search_content('nm', name, results)
         name = _findBetween(cont, '<title>', '</title>')
         res = []
         if not name: return res
@@ -491,12 +504,28 @@ class IMDbMobileAccessSystem(IMDbHTTPAccessSystem):
                 role = u''
                 if not istvguest:
                     ms = m.split('....')
-                    if len(ms) >= 1:
-                        first = ms[0]
-                        if first and first[0] == '(':
-                            notes = first.strip()
-                        ms = ms[1:]
-                    if ms: role = ' '.join(ms).strip()
+                    if len(ms) == 2:
+                        notes = ms[0].strip().replace('  ', ' ')
+                        role = ms[1].strip()
+                        fn = role.find('(')
+                        if fn != -1:
+                            en = role.rfind(')')
+                            pnote = role[fn:en+1].strip()
+                            role = '%s %s' % (role[:fn].strip(),
+                                            role[en+1:].strip())
+                            role = role.strip()
+                            if pnote:
+                                if notes: notes += ' '
+                                notes += pnote
+                    else:
+                        notes = ''.join(ms).strip().replace('  ', ' ')
+                        role = u''
+                    #if len(ms) >= 1:
+                    #    first = ms[0]
+                    #    if first and first[0] == '(':
+                    #        notes = first.strip()
+                    #    ms = ms[1:]
+                    #if ms: role = ' '.join(ms).strip()
                 else:
                     # XXX: strip quotes from strings like "Himself"?
                     noteidx = m.find('(')
